# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aiExchangeMessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='aiExchangeMessages.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\220\001\000'),
  serialized_pb=_b('\n\x18\x61iExchangeMessages.proto\"\"\n\x0b\x44\x61taRequest\x12\x13\n\x0brequest_ids\x18\x01 \x03(\t\"\xf5\x07\n\x0c\x44\x61taResponse\x12%\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x17.DataResponse.DataEntry\x1a\xfc\x06\n\x04\x44\x61ta\x12/\n\x08position\x18\x01 \x01(\x0b\x32\x1b.DataResponse.Data.PositionH\x00\x12)\n\x05speed\x18\x02 \x01(\x0b\x32\x18.DataResponse.Data.SpeedH\x00\x12\x31\n\x05\x61ngle\x18\x03 \x01(\x0b\x32 .DataResponse.Data.SteeringAngleH\x00\x12)\n\x05lidar\x18\x04 \x01(\x0b\x32\x18.DataResponse.Data.LidarH\x00\x12+\n\x06\x63\x61mera\x18\x05 \x01(\x0b\x32\x19.DataResponse.Data.CameraH\x00\x12+\n\x06\x64\x61mage\x18\x06 \x01(\x0b\x32\x19.DataResponse.Data.DamageH\x00\x12\x45\n\x14lane_center_distance\x18\x07 \x01(\x0b\x32%.DataResponse.Data.LaneCenterDistanceH\x00\x12>\n\x11\x63\x61r_to_lane_angle\x18\x08 \x01(\x0b\x32!.DataResponse.Data.CarToLaneAngleH\x00\x12\x36\n\x0c\x62ounding_box\x18\t \x01(\x0b\x32\x1e.DataResponse.Data.BoundingBoxH\x00\x12)\n\x05\x65rror\x18\n \x01(\x0b\x32\x18.DataResponse.Data.ErrorH\x00\x1a \n\x08Position\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x1a\x16\n\x05Speed\x12\r\n\x05speed\x18\x01 \x01(\x01\x1a\x1e\n\rSteeringAngle\x12\r\n\x05\x61ngle\x18\x01 \x01(\x01\x1a\x17\n\x05Lidar\x12\x0e\n\x06points\x18\x01 \x03(\x01\x1a\x39\n\x06\x43\x61mera\x12\r\n\x05\x63olor\x18\x01 \x01(\x0c\x12\x11\n\tannotated\x18\x02 \x01(\x0c\x12\r\n\x05\x64\x65pth\x18\x03 \x01(\x0c\x1a\x1c\n\x06\x44\x61mage\x12\x12\n\nis_damaged\x18\x01 \x01(\x08\x1a\x37\n\x12LaneCenterDistance\x12\x0f\n\x07lane_id\x18\x01 \x01(\t\x12\x10\n\x08\x64istance\x18\x02 \x01(\x02\x1a\x30\n\x0e\x43\x61rToLaneAngle\x12\x0f\n\x07lane_id\x18\x01 \x01(\t\x12\r\n\x05\x61ngle\x18\x02 \x01(\x02\x1a\x1d\n\x0b\x42oundingBox\x12\x0e\n\x06points\x18\x01 \x03(\x02\x1a\x18\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\tB\x06\n\x04\x64\x61ta\x1a?\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.DataResponse.Data:\x02\x38\x01\"\x91\x02\n\x07\x43ontrol\x12\'\n\tavCommand\x18\x01 \x01(\x0b\x32\x12.Control.AvCommandH\x00\x12)\n\nsimCommand\x18\x02 \x01(\x0b\x32\x13.Control.SimCommandH\x00\x1a=\n\tAvCommand\x12\x12\n\naccelerate\x18\x01 \x01(\x01\x12\r\n\x05steer\x18\x02 \x01(\x01\x12\r\n\x05\x62rake\x18\x03 \x01(\x01\x1ah\n\nSimCommand\x12,\n\x07\x63ommand\x18\x01 \x01(\x0e\x32\x1b.Control.SimCommand.Command\",\n\x07\x43ommand\x12\x0b\n\x07SUCCEED\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01\x12\n\n\x06\x43\x41NCEL\x10\x02\x42\t\n\x07\x63ommand\"L\n\x12VerificationResult\x12\x14\n\x0cprecondition\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x61ilure\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\t\"\x18\n\tVehicleID\x12\x0b\n\x03vid\x18\x01 \x01(\t\"\x1a\n\nVehicleIDs\x12\x0c\n\x04vids\x18\x01 \x03(\t\"\x1b\n\x0cSimulationID\x12\x0b\n\x03sid\x18\x01 \x01(\t\"\x1d\n\rSimulationIDs\x12\x0c\n\x04sids\x18\x01 \x03(\t\"\x88\x02\n\x10SubmissionResult\x12/\n\x06result\x18\x01 \x01(\x0b\x32\x1d.SubmissionResult.SubmissionsH\x00\x12\x18\n\x07message\x18\x02 \x01(\x0b\x32\x05.VoidH\x00\x1a\x95\x01\n\x0bSubmissions\x12\x43\n\x0bsubmissions\x18\x01 \x03(\x0b\x32..SubmissionResult.Submissions.SubmissionsEntry\x1a\x41\n\x10SubmissionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1c\n\x05value\x18\x02 \x01(\x0b\x32\r.SimulationID:\x02\x38\x01\x42\x11\n\x0fmay_submissions\" \n\x10SimulationNodeID\x12\x0c\n\x04snid\x18\x01 \x01(\t\"\x12\n\x03Num\x12\x0b\n\x03num\x18\x01 \x01(\x05\"\x15\n\x04\x42ool\x12\r\n\x05value\x18\x01 \x01(\x08\"\x99\x01\n\x10SimStateResponse\x12)\n\x05state\x18\x01 \x01(\x0e\x32\x1a.SimStateResponse.SimState\"Z\n\x08SimState\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0c\n\x08\x46INISHED\x10\x02\x12\x0c\n\x08\x43\x41NCELED\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0b\n\x07UNKNOWN\x10\x05\"|\n\nTestResult\x12\"\n\x06result\x18\x01 \x01(\x0e\x32\x12.TestResult.Result\"J\n\x06Result\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x12\x0b\n\x07SKIPPED\x10\x03\x12\x0b\n\x07UNKNOWN\x10\x04\"\x17\n\x04Void\x12\x0f\n\x07message\x18\x01 \x01(\t\"*\n\x04User\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\tB\x03\x90\x01\x00\x62\x06proto3')
)



_CONTROL_SIMCOMMAND_COMMAND = _descriptor.EnumDescriptor(
  name='Command',
  full_name='Control.SimCommand.Command',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCEED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCEL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1299,
  serialized_end=1343,
)
_sym_db.RegisterEnumDescriptor(_CONTROL_SIMCOMMAND_COMMAND)

_SIMSTATERESPONSE_SIMSTATE = _descriptor.EnumDescriptor(
  name='SimState',
  full_name='SimStateResponse.SimState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1956,
  serialized_end=2046,
)
_sym_db.RegisterEnumDescriptor(_SIMSTATERESPONSE_SIMSTATE)

_TESTRESULT_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='TestResult.Result',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2098,
  serialized_end=2172,
)
_sym_db.RegisterEnumDescriptor(_TESTRESULT_RESULT)


_DATAREQUEST = _descriptor.Descriptor(
  name='DataRequest',
  full_name='DataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_ids', full_name='DataRequest.request_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28,
  serialized_end=62,
)


_DATARESPONSE_DATA_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='DataResponse.Data.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='DataResponse.Data.Position.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='DataResponse.Data.Position.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=671,
)

_DATARESPONSE_DATA_SPEED = _descriptor.Descriptor(
  name='Speed',
  full_name='DataResponse.Data.Speed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='DataResponse.Data.Speed.speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=695,
)

_DATARESPONSE_DATA_STEERINGANGLE = _descriptor.Descriptor(
  name='SteeringAngle',
  full_name='DataResponse.Data.SteeringAngle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angle', full_name='DataResponse.Data.SteeringAngle.angle', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=727,
)

_DATARESPONSE_DATA_LIDAR = _descriptor.Descriptor(
  name='Lidar',
  full_name='DataResponse.Data.Lidar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='DataResponse.Data.Lidar.points', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=752,
)

_DATARESPONSE_DATA_CAMERA = _descriptor.Descriptor(
  name='Camera',
  full_name='DataResponse.Data.Camera',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='DataResponse.Data.Camera.color', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotated', full_name='DataResponse.Data.Camera.annotated', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depth', full_name='DataResponse.Data.Camera.depth', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=811,
)

_DATARESPONSE_DATA_DAMAGE = _descriptor.Descriptor(
  name='Damage',
  full_name='DataResponse.Data.Damage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_damaged', full_name='DataResponse.Data.Damage.is_damaged', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=813,
  serialized_end=841,
)

_DATARESPONSE_DATA_LANECENTERDISTANCE = _descriptor.Descriptor(
  name='LaneCenterDistance',
  full_name='DataResponse.Data.LaneCenterDistance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='DataResponse.Data.LaneCenterDistance.lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distance', full_name='DataResponse.Data.LaneCenterDistance.distance', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=898,
)

_DATARESPONSE_DATA_CARTOLANEANGLE = _descriptor.Descriptor(
  name='CarToLaneAngle',
  full_name='DataResponse.Data.CarToLaneAngle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='DataResponse.Data.CarToLaneAngle.lane_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='DataResponse.Data.CarToLaneAngle.angle', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=948,
)

_DATARESPONSE_DATA_BOUNDINGBOX = _descriptor.Descriptor(
  name='BoundingBox',
  full_name='DataResponse.Data.BoundingBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='DataResponse.Data.BoundingBox.points', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=979,
)

_DATARESPONSE_DATA_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='DataResponse.Data.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='DataResponse.Data.Error.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=981,
  serialized_end=1005,
)

_DATARESPONSE_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='DataResponse.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='DataResponse.Data.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='DataResponse.Data.speed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='angle', full_name='DataResponse.Data.angle', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lidar', full_name='DataResponse.Data.lidar', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='camera', full_name='DataResponse.Data.camera', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='damage', full_name='DataResponse.Data.damage', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lane_center_distance', full_name='DataResponse.Data.lane_center_distance', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='car_to_lane_angle', full_name='DataResponse.Data.car_to_lane_angle', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bounding_box', full_name='DataResponse.Data.bounding_box', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='DataResponse.Data.error', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATARESPONSE_DATA_POSITION, _DATARESPONSE_DATA_SPEED, _DATARESPONSE_DATA_STEERINGANGLE, _DATARESPONSE_DATA_LIDAR, _DATARESPONSE_DATA_CAMERA, _DATARESPONSE_DATA_DAMAGE, _DATARESPONSE_DATA_LANECENTERDISTANCE, _DATARESPONSE_DATA_CARTOLANEANGLE, _DATARESPONSE_DATA_BOUNDINGBOX, _DATARESPONSE_DATA_ERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='DataResponse.Data.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=121,
  serialized_end=1013,
)

_DATARESPONSE_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='DataResponse.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='DataResponse.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='DataResponse.DataEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1078,
)

_DATARESPONSE = _descriptor.Descriptor(
  name='DataResponse',
  full_name='DataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='DataResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATARESPONSE_DATA, _DATARESPONSE_DATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=1078,
)


_CONTROL_AVCOMMAND = _descriptor.Descriptor(
  name='AvCommand',
  full_name='Control.AvCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accelerate', full_name='Control.AvCommand.accelerate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steer', full_name='Control.AvCommand.steer', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='brake', full_name='Control.AvCommand.brake', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1237,
)

_CONTROL_SIMCOMMAND = _descriptor.Descriptor(
  name='SimCommand',
  full_name='Control.SimCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='Control.SimCommand.command', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTROL_SIMCOMMAND_COMMAND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1343,
)

_CONTROL = _descriptor.Descriptor(
  name='Control',
  full_name='Control',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='avCommand', full_name='Control.avCommand', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simCommand', full_name='Control.simCommand', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONTROL_AVCOMMAND, _CONTROL_SIMCOMMAND, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='Control.command',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1081,
  serialized_end=1354,
)


_VERIFICATIONRESULT = _descriptor.Descriptor(
  name='VerificationResult',
  full_name='VerificationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='precondition', full_name='VerificationResult.precondition', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failure', full_name='VerificationResult.failure', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='VerificationResult.success', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1356,
  serialized_end=1432,
)


_VEHICLEID = _descriptor.Descriptor(
  name='VehicleID',
  full_name='VehicleID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vid', full_name='VehicleID.vid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1434,
  serialized_end=1458,
)


_VEHICLEIDS = _descriptor.Descriptor(
  name='VehicleIDs',
  full_name='VehicleIDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vids', full_name='VehicleIDs.vids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1460,
  serialized_end=1486,
)


_SIMULATIONID = _descriptor.Descriptor(
  name='SimulationID',
  full_name='SimulationID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sid', full_name='SimulationID.sid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1515,
)


_SIMULATIONIDS = _descriptor.Descriptor(
  name='SimulationIDs',
  full_name='SimulationIDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sids', full_name='SimulationIDs.sids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1517,
  serialized_end=1546,
)


_SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY = _descriptor.Descriptor(
  name='SubmissionsEntry',
  full_name='SubmissionResult.Submissions.SubmissionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='SubmissionResult.Submissions.SubmissionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='SubmissionResult.Submissions.SubmissionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1794,
)

_SUBMISSIONRESULT_SUBMISSIONS = _descriptor.Descriptor(
  name='Submissions',
  full_name='SubmissionResult.Submissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='submissions', full_name='SubmissionResult.Submissions.submissions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1645,
  serialized_end=1794,
)

_SUBMISSIONRESULT = _descriptor.Descriptor(
  name='SubmissionResult',
  full_name='SubmissionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='SubmissionResult.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='SubmissionResult.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBMISSIONRESULT_SUBMISSIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='may_submissions', full_name='SubmissionResult.may_submissions',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1549,
  serialized_end=1813,
)


_SIMULATIONNODEID = _descriptor.Descriptor(
  name='SimulationNodeID',
  full_name='SimulationNodeID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snid', full_name='SimulationNodeID.snid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1847,
)


_NUM = _descriptor.Descriptor(
  name='Num',
  full_name='Num',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='Num.num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1849,
  serialized_end=1867,
)


_BOOL = _descriptor.Descriptor(
  name='Bool',
  full_name='Bool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Bool.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1869,
  serialized_end=1890,
)


_SIMSTATERESPONSE = _descriptor.Descriptor(
  name='SimStateResponse',
  full_name='SimStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='SimStateResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIMSTATERESPONSE_SIMSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1893,
  serialized_end=2046,
)


_TESTRESULT = _descriptor.Descriptor(
  name='TestResult',
  full_name='TestResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='TestResult.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TESTRESULT_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2048,
  serialized_end=2172,
)


_VOID = _descriptor.Descriptor(
  name='Void',
  full_name='Void',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='Void.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2197,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='User.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='password', full_name='User.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2199,
  serialized_end=2241,
)

_DATARESPONSE_DATA_POSITION.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_SPEED.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_STEERINGANGLE.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_LIDAR.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_CAMERA.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_DAMAGE.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_LANECENTERDISTANCE.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_CARTOLANEANGLE.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_BOUNDINGBOX.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA_ERROR.containing_type = _DATARESPONSE_DATA
_DATARESPONSE_DATA.fields_by_name['position'].message_type = _DATARESPONSE_DATA_POSITION
_DATARESPONSE_DATA.fields_by_name['speed'].message_type = _DATARESPONSE_DATA_SPEED
_DATARESPONSE_DATA.fields_by_name['angle'].message_type = _DATARESPONSE_DATA_STEERINGANGLE
_DATARESPONSE_DATA.fields_by_name['lidar'].message_type = _DATARESPONSE_DATA_LIDAR
_DATARESPONSE_DATA.fields_by_name['camera'].message_type = _DATARESPONSE_DATA_CAMERA
_DATARESPONSE_DATA.fields_by_name['damage'].message_type = _DATARESPONSE_DATA_DAMAGE
_DATARESPONSE_DATA.fields_by_name['lane_center_distance'].message_type = _DATARESPONSE_DATA_LANECENTERDISTANCE
_DATARESPONSE_DATA.fields_by_name['car_to_lane_angle'].message_type = _DATARESPONSE_DATA_CARTOLANEANGLE
_DATARESPONSE_DATA.fields_by_name['bounding_box'].message_type = _DATARESPONSE_DATA_BOUNDINGBOX
_DATARESPONSE_DATA.fields_by_name['error'].message_type = _DATARESPONSE_DATA_ERROR
_DATARESPONSE_DATA.containing_type = _DATARESPONSE
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['position'])
_DATARESPONSE_DATA.fields_by_name['position'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['speed'])
_DATARESPONSE_DATA.fields_by_name['speed'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['angle'])
_DATARESPONSE_DATA.fields_by_name['angle'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['lidar'])
_DATARESPONSE_DATA.fields_by_name['lidar'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['camera'])
_DATARESPONSE_DATA.fields_by_name['camera'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['damage'])
_DATARESPONSE_DATA.fields_by_name['damage'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['lane_center_distance'])
_DATARESPONSE_DATA.fields_by_name['lane_center_distance'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['car_to_lane_angle'])
_DATARESPONSE_DATA.fields_by_name['car_to_lane_angle'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['bounding_box'])
_DATARESPONSE_DATA.fields_by_name['bounding_box'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATA.oneofs_by_name['data'].fields.append(
  _DATARESPONSE_DATA.fields_by_name['error'])
_DATARESPONSE_DATA.fields_by_name['error'].containing_oneof = _DATARESPONSE_DATA.oneofs_by_name['data']
_DATARESPONSE_DATAENTRY.fields_by_name['value'].message_type = _DATARESPONSE_DATA
_DATARESPONSE_DATAENTRY.containing_type = _DATARESPONSE
_DATARESPONSE.fields_by_name['data'].message_type = _DATARESPONSE_DATAENTRY
_CONTROL_AVCOMMAND.containing_type = _CONTROL
_CONTROL_SIMCOMMAND.fields_by_name['command'].enum_type = _CONTROL_SIMCOMMAND_COMMAND
_CONTROL_SIMCOMMAND.containing_type = _CONTROL
_CONTROL_SIMCOMMAND_COMMAND.containing_type = _CONTROL_SIMCOMMAND
_CONTROL.fields_by_name['avCommand'].message_type = _CONTROL_AVCOMMAND
_CONTROL.fields_by_name['simCommand'].message_type = _CONTROL_SIMCOMMAND
_CONTROL.oneofs_by_name['command'].fields.append(
  _CONTROL.fields_by_name['avCommand'])
_CONTROL.fields_by_name['avCommand'].containing_oneof = _CONTROL.oneofs_by_name['command']
_CONTROL.oneofs_by_name['command'].fields.append(
  _CONTROL.fields_by_name['simCommand'])
_CONTROL.fields_by_name['simCommand'].containing_oneof = _CONTROL.oneofs_by_name['command']
_SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY.fields_by_name['value'].message_type = _SIMULATIONID
_SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY.containing_type = _SUBMISSIONRESULT_SUBMISSIONS
_SUBMISSIONRESULT_SUBMISSIONS.fields_by_name['submissions'].message_type = _SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY
_SUBMISSIONRESULT_SUBMISSIONS.containing_type = _SUBMISSIONRESULT
_SUBMISSIONRESULT.fields_by_name['result'].message_type = _SUBMISSIONRESULT_SUBMISSIONS
_SUBMISSIONRESULT.fields_by_name['message'].message_type = _VOID
_SUBMISSIONRESULT.oneofs_by_name['may_submissions'].fields.append(
  _SUBMISSIONRESULT.fields_by_name['result'])
_SUBMISSIONRESULT.fields_by_name['result'].containing_oneof = _SUBMISSIONRESULT.oneofs_by_name['may_submissions']
_SUBMISSIONRESULT.oneofs_by_name['may_submissions'].fields.append(
  _SUBMISSIONRESULT.fields_by_name['message'])
_SUBMISSIONRESULT.fields_by_name['message'].containing_oneof = _SUBMISSIONRESULT.oneofs_by_name['may_submissions']
_SIMSTATERESPONSE.fields_by_name['state'].enum_type = _SIMSTATERESPONSE_SIMSTATE
_SIMSTATERESPONSE_SIMSTATE.containing_type = _SIMSTATERESPONSE
_TESTRESULT.fields_by_name['result'].enum_type = _TESTRESULT_RESULT
_TESTRESULT_RESULT.containing_type = _TESTRESULT
DESCRIPTOR.message_types_by_name['DataRequest'] = _DATAREQUEST
DESCRIPTOR.message_types_by_name['DataResponse'] = _DATARESPONSE
DESCRIPTOR.message_types_by_name['Control'] = _CONTROL
DESCRIPTOR.message_types_by_name['VerificationResult'] = _VERIFICATIONRESULT
DESCRIPTOR.message_types_by_name['VehicleID'] = _VEHICLEID
DESCRIPTOR.message_types_by_name['VehicleIDs'] = _VEHICLEIDS
DESCRIPTOR.message_types_by_name['SimulationID'] = _SIMULATIONID
DESCRIPTOR.message_types_by_name['SimulationIDs'] = _SIMULATIONIDS
DESCRIPTOR.message_types_by_name['SubmissionResult'] = _SUBMISSIONRESULT
DESCRIPTOR.message_types_by_name['SimulationNodeID'] = _SIMULATIONNODEID
DESCRIPTOR.message_types_by_name['Num'] = _NUM
DESCRIPTOR.message_types_by_name['Bool'] = _BOOL
DESCRIPTOR.message_types_by_name['SimStateResponse'] = _SIMSTATERESPONSE
DESCRIPTOR.message_types_by_name['TestResult'] = _TESTRESULT
DESCRIPTOR.message_types_by_name['Void'] = _VOID
DESCRIPTOR.message_types_by_name['User'] = _USER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataRequest = _reflection.GeneratedProtocolMessageType('DataRequest', (_message.Message,), dict(
  DESCRIPTOR = _DATAREQUEST,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:DataRequest)
  ))
_sym_db.RegisterMessage(DataRequest)

DataResponse = _reflection.GeneratedProtocolMessageType('DataResponse', (_message.Message,), dict(

  Data = _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), dict(

    Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_POSITION,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.Position)
      ))
    ,

    Speed = _reflection.GeneratedProtocolMessageType('Speed', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_SPEED,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.Speed)
      ))
    ,

    SteeringAngle = _reflection.GeneratedProtocolMessageType('SteeringAngle', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_STEERINGANGLE,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.SteeringAngle)
      ))
    ,

    Lidar = _reflection.GeneratedProtocolMessageType('Lidar', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_LIDAR,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.Lidar)
      ))
    ,

    Camera = _reflection.GeneratedProtocolMessageType('Camera', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_CAMERA,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.Camera)
      ))
    ,

    Damage = _reflection.GeneratedProtocolMessageType('Damage', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_DAMAGE,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.Damage)
      ))
    ,

    LaneCenterDistance = _reflection.GeneratedProtocolMessageType('LaneCenterDistance', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_LANECENTERDISTANCE,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.LaneCenterDistance)
      ))
    ,

    CarToLaneAngle = _reflection.GeneratedProtocolMessageType('CarToLaneAngle', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_CARTOLANEANGLE,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.CarToLaneAngle)
      ))
    ,

    BoundingBox = _reflection.GeneratedProtocolMessageType('BoundingBox', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_BOUNDINGBOX,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.BoundingBox)
      ))
    ,

    Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
      DESCRIPTOR = _DATARESPONSE_DATA_ERROR,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:DataResponse.Data.Error)
      ))
    ,
    DESCRIPTOR = _DATARESPONSE_DATA,
    __module__ = 'aiExchangeMessages_pb2'
    # @@protoc_insertion_point(class_scope:DataResponse.Data)
    ))
  ,

  DataEntry = _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), dict(
    DESCRIPTOR = _DATARESPONSE_DATAENTRY,
    __module__ = 'aiExchangeMessages_pb2'
    # @@protoc_insertion_point(class_scope:DataResponse.DataEntry)
    ))
  ,
  DESCRIPTOR = _DATARESPONSE,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:DataResponse)
  ))
_sym_db.RegisterMessage(DataResponse)
_sym_db.RegisterMessage(DataResponse.Data)
_sym_db.RegisterMessage(DataResponse.Data.Position)
_sym_db.RegisterMessage(DataResponse.Data.Speed)
_sym_db.RegisterMessage(DataResponse.Data.SteeringAngle)
_sym_db.RegisterMessage(DataResponse.Data.Lidar)
_sym_db.RegisterMessage(DataResponse.Data.Camera)
_sym_db.RegisterMessage(DataResponse.Data.Damage)
_sym_db.RegisterMessage(DataResponse.Data.LaneCenterDistance)
_sym_db.RegisterMessage(DataResponse.Data.CarToLaneAngle)
_sym_db.RegisterMessage(DataResponse.Data.BoundingBox)
_sym_db.RegisterMessage(DataResponse.Data.Error)
_sym_db.RegisterMessage(DataResponse.DataEntry)

Control = _reflection.GeneratedProtocolMessageType('Control', (_message.Message,), dict(

  AvCommand = _reflection.GeneratedProtocolMessageType('AvCommand', (_message.Message,), dict(
    DESCRIPTOR = _CONTROL_AVCOMMAND,
    __module__ = 'aiExchangeMessages_pb2'
    # @@protoc_insertion_point(class_scope:Control.AvCommand)
    ))
  ,

  SimCommand = _reflection.GeneratedProtocolMessageType('SimCommand', (_message.Message,), dict(
    DESCRIPTOR = _CONTROL_SIMCOMMAND,
    __module__ = 'aiExchangeMessages_pb2'
    # @@protoc_insertion_point(class_scope:Control.SimCommand)
    ))
  ,
  DESCRIPTOR = _CONTROL,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:Control)
  ))
_sym_db.RegisterMessage(Control)
_sym_db.RegisterMessage(Control.AvCommand)
_sym_db.RegisterMessage(Control.SimCommand)

VerificationResult = _reflection.GeneratedProtocolMessageType('VerificationResult', (_message.Message,), dict(
  DESCRIPTOR = _VERIFICATIONRESULT,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:VerificationResult)
  ))
_sym_db.RegisterMessage(VerificationResult)

VehicleID = _reflection.GeneratedProtocolMessageType('VehicleID', (_message.Message,), dict(
  DESCRIPTOR = _VEHICLEID,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:VehicleID)
  ))
_sym_db.RegisterMessage(VehicleID)

VehicleIDs = _reflection.GeneratedProtocolMessageType('VehicleIDs', (_message.Message,), dict(
  DESCRIPTOR = _VEHICLEIDS,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:VehicleIDs)
  ))
_sym_db.RegisterMessage(VehicleIDs)

SimulationID = _reflection.GeneratedProtocolMessageType('SimulationID', (_message.Message,), dict(
  DESCRIPTOR = _SIMULATIONID,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:SimulationID)
  ))
_sym_db.RegisterMessage(SimulationID)

SimulationIDs = _reflection.GeneratedProtocolMessageType('SimulationIDs', (_message.Message,), dict(
  DESCRIPTOR = _SIMULATIONIDS,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:SimulationIDs)
  ))
_sym_db.RegisterMessage(SimulationIDs)

SubmissionResult = _reflection.GeneratedProtocolMessageType('SubmissionResult', (_message.Message,), dict(

  Submissions = _reflection.GeneratedProtocolMessageType('Submissions', (_message.Message,), dict(

    SubmissionsEntry = _reflection.GeneratedProtocolMessageType('SubmissionsEntry', (_message.Message,), dict(
      DESCRIPTOR = _SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY,
      __module__ = 'aiExchangeMessages_pb2'
      # @@protoc_insertion_point(class_scope:SubmissionResult.Submissions.SubmissionsEntry)
      ))
    ,
    DESCRIPTOR = _SUBMISSIONRESULT_SUBMISSIONS,
    __module__ = 'aiExchangeMessages_pb2'
    # @@protoc_insertion_point(class_scope:SubmissionResult.Submissions)
    ))
  ,
  DESCRIPTOR = _SUBMISSIONRESULT,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:SubmissionResult)
  ))
_sym_db.RegisterMessage(SubmissionResult)
_sym_db.RegisterMessage(SubmissionResult.Submissions)
_sym_db.RegisterMessage(SubmissionResult.Submissions.SubmissionsEntry)

SimulationNodeID = _reflection.GeneratedProtocolMessageType('SimulationNodeID', (_message.Message,), dict(
  DESCRIPTOR = _SIMULATIONNODEID,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:SimulationNodeID)
  ))
_sym_db.RegisterMessage(SimulationNodeID)

Num = _reflection.GeneratedProtocolMessageType('Num', (_message.Message,), dict(
  DESCRIPTOR = _NUM,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:Num)
  ))
_sym_db.RegisterMessage(Num)

Bool = _reflection.GeneratedProtocolMessageType('Bool', (_message.Message,), dict(
  DESCRIPTOR = _BOOL,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:Bool)
  ))
_sym_db.RegisterMessage(Bool)

SimStateResponse = _reflection.GeneratedProtocolMessageType('SimStateResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIMSTATERESPONSE,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:SimStateResponse)
  ))
_sym_db.RegisterMessage(SimStateResponse)

TestResult = _reflection.GeneratedProtocolMessageType('TestResult', (_message.Message,), dict(
  DESCRIPTOR = _TESTRESULT,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:TestResult)
  ))
_sym_db.RegisterMessage(TestResult)

Void = _reflection.GeneratedProtocolMessageType('Void', (_message.Message,), dict(
  DESCRIPTOR = _VOID,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:Void)
  ))
_sym_db.RegisterMessage(Void)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), dict(
  DESCRIPTOR = _USER,
  __module__ = 'aiExchangeMessages_pb2'
  # @@protoc_insertion_point(class_scope:User)
  ))
_sym_db.RegisterMessage(User)


DESCRIPTOR._options = None
_DATARESPONSE_DATAENTRY._options = None
_SUBMISSIONRESULT_SUBMISSIONS_SUBMISSIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)
